package com.ruoyi.bst.article.mapper;

import java.util.List;
import com.ruoyi.bst.article.domain.Article;
import com.ruoyi.bst.article.domain.ArticleVO;
import com.ruoyi.bst.article.domain.ArticleQuery;
import com.ruoyi.bst.articleCategory.domain.ArticleCategoryQuery;
import org.apache.ibatis.annotations.Param;

/**
 * 文章Mapper接口
 *
 * @author ruoyi
 * @date 2025-03-27
 */
public interface ArticleMapper
{
    /**
     * 查询文章
     *
     * @param id 文章主键
     * @return 文章
     */
    ArticleVO selectArticleById(Long id);

    /**
     * 查询文章列表
     *
     * @param query 文章
     * @return 文章集合
     */
    List<ArticleVO> selectArticleList(@Param("query")ArticleQuery query);

    /**
     * 新增文章
     *
     * @param article 文章
     * @return 结果
     */
    int insertArticle(Article article);

    /**
     * 批量新增文章
     */
    int batchInsert(@Param("list") List<? extends Article> list);

    /**
     * 批量修改文章
     */
    int batchUpdate(@Param("list") List<? extends Article> list);

    /**
     * 修改文章
     *
     * @param article 文章
     * @return 结果
     */
    public int updateArticle(@Param("data") Article article);

    /**
     * 删除文章
     *
     * @param id 文章主键
     * @return 结果
     */
    int deleteArticleById(Long id);

    /**
     * 批量删除文章
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteArticleByIds(Long[] ids);

    public List<ArticleVO> selectChildrenById(Long id);

    ArticleVO selectArticleByCode(ArticleCategoryQuery articleCategoryQuery);
}
